@@ -2,10 +2,11 @@ use Map::Metro::Standard::Moops;
 use strict;
 use warnings;
 
-our $VERSION = '0.2208'; # VERSION
+our $VERSION = '0.2300'; # VERSION
 # PODNAME: Map::Metro::Cmd::Graphviz
+# ABSTRACT: Make a visualization using GraphViz2
 
-class Map::Metro::Cmd::Graphviz extends Map::Metro::Cmd using Moose {
+class Map::Metro::Cmd::Graphviz extends Map::Metro::Cmd {
 
     use MooseX::App::Command;
     use Path::Tiny;
@@ -138,11 +139,11 @@ __END__
 
 =head1 NAME
 
-Map::Metro::Cmd::Graphviz
+Map::Metro::Cmd::Graphviz - Make a visualization using GraphViz2
 
 =head1 VERSION
 
-Version 0.2208, released 2015-10-27.
+Version 0.2300, released 2016-01-14.
 
 =head1 SOURCE
 
@@ -158,7 +159,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
