@@ -2,10 +2,11 @@ use Map::Metro::Standard::Moops;
 use strict;
 use warnings;
 
-our $VERSION = '0.2208'; # VERSION
+our $VERSION = '0.2300'; # VERSION
+# ABSTRACT: StationNameDoesNotExistInStationList
 # PODNAME: Map::Metro::Exception::StationNameDoesNotExistInStationList
 
-class Map::Metro::Exception::StationNameDoesNotExistInStationList with Map::Metro::Exception using Moose  {
+class Map::Metro::Exception::StationNameDoesNotExistInStationList with Map::Metro::Exception {
 
     use Map::Metro::Exception -all;
 
@@ -33,11 +34,11 @@ __END__
 
 =head1 NAME
 
-Map::Metro::Exception::StationNameDoesNotExistInStationList
+Map::Metro::Exception::StationNameDoesNotExistInStationList - StationNameDoesNotExistInStationList
 
 =head1 VERSION
 
-Version 0.2208, released 2015-10-27.
+Version 0.2300, released 2016-01-14.
 
 =head1 SOURCE
 
@@ -53,7 +54,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
