@@ -2,11 +2,11 @@ use Map::Metro::Standard::Moops;
 use strict;
 use warnings;
 
-our $VERSION = '0.2208'; # VERSION
+our $VERSION = '0.2300'; # VERSION
 # PODNAME: Map::Metro::Graph::Connection
-# ABSTRACT: What is a connection?
+# ABSTRACT: Connects two stations on a line
 
-class Map::Metro::Graph::Connection using Moose {
+class Map::Metro::Graph::Connection {
 
     has origin_line_station => (
         is => 'ro',
@@ -46,11 +46,11 @@ __END__
 
 =head1 NAME
 
-Map::Metro::Graph::Connection - What is a connection?
+Map::Metro::Graph::Connection - Connects two stations on a line
 
 =head1 VERSION
 
-Version 0.2208, released 2015-10-27.
+Version 0.2300, released 2016-01-14.
 
 =head1 DESCRIPTION
 
@@ -73,7 +73,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
