@@ -2,11 +2,11 @@ use Map::Metro::Standard::Moops;
 use strict;
 use warnings;
 
-our $VERSION = '0.2208'; # VERSION
+our $VERSION = '0.2300'; # VERSION
 # PODNAME: Map::Metro::Graph::Line
-# ABSTRACT: What is a line?
+# ABSTRACT: Meta information about a line
 
-class Map::Metro::Graph::Line using Moose {
+class Map::Metro::Graph::Line {
 
     has id => (
         is => 'ro',
@@ -52,11 +52,11 @@ __END__
 
 =head1 NAME
 
-Map::Metro::Graph::Line - What is a line?
+Map::Metro::Graph::Line - Meta information about a line
 
 =head1 VERSION
 
-Version 0.2208, released 2015-10-27.
+Version 0.2300, released 2016-01-14.
 
 =head1 DESCRIPTION
 
@@ -90,7 +90,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
