@@ -2,11 +2,11 @@ use Map::Metro::Standard::Moops;
 use strict;
 use warnings;
 
-our $VERSION = '0.2208'; # VERSION
+our $VERSION = '0.2300'; # VERSION
 # PODNAME: Map::Metro::Graph::Transfer
-# ABSTRACT: What is a transfer?
+# ABSTRACT: Moving between two stations without a connection between them
 
-class Map::Metro::Graph::Transfer using Moose {
+class Map::Metro::Graph::Transfer {
 
     has origin_station => (
         is => 'ro',
@@ -36,11 +36,11 @@ __END__
 
 =head1 NAME
 
-Map::Metro::Graph::Transfer - What is a transfer?
+Map::Metro::Graph::Transfer - Moving between two stations without a connection between them
 
 =head1 VERSION
 
-Version 0.2208, released 2015-10-27.
+Version 0.2300, released 2016-01-14.
 
 =head1 DESCRIPTION
 
@@ -78,7 +78,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
