@@ -2,11 +2,11 @@ use Map::Metro::Standard::Moops;
 use strict;
 use warnings;
 
-our $VERSION = '0.2208'; # VERSION
+our $VERSION = '0.2300'; # VERSION
 # PODNAME: Map::Metro::Hook
 # ABSTRACT: Hook into Map::Metro
 
-class Map::Metro::Hook using Moose {
+class Map::Metro::Hook {
 
     use Type::Tiny::Enum;
 
@@ -46,7 +46,7 @@ Map::Metro::Hook - Hook into Map::Metro
 
 =head1 VERSION
 
-Version 0.2208, released 2015-10-27.
+Version 0.2300, released 2016-01-14.
 
 =head1 SYNOPSIS
 
@@ -170,7 +170,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
