@@ -2,10 +2,11 @@ use Map::Metro::Standard::Moops;
 use strict;
 use warnings;
 
-our $VERSION = '0.2208'; # VERSION
+our $VERSION = '0.2300'; # VERSION
 # PODNAME: Map::Metro::Plugin::Hook::PrettyPrinter
+# ABSTRACT: Prints a routing
 
-class Map::Metro::Plugin::Hook::PrettyPrinter using Moose {
+class Map::Metro::Plugin::Hook::PrettyPrinter {
 
     method register {
         before_add_routing => sub {
@@ -77,11 +78,11 @@ __END__
 
 =head1 NAME
 
-Map::Metro::Plugin::Hook::PrettyPrinter
+Map::Metro::Plugin::Hook::PrettyPrinter - Prints a routing
 
 =head1 VERSION
 
-Version 0.2208, released 2015-10-27.
+Version 0.2300, released 2016-01-14.
 
 =head1 SOURCE
 
@@ -97,7 +98,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
