@@ -2,7 +2,9 @@ use feature ':5.16';
 use strict;
 use warnings;
 
-our $VERSION = '0.2208'; # VERSION
+our $VERSION = '0.2300'; # VERSION
+# PODCLASSNAME
+# ABSTRACT: Prints stations as they are parsed
 
 package Map::Metro::Plugin::Hook::StreamStations {
 
@@ -41,11 +43,11 @@ __END__
 
 =head1 NAME
 
-Map::Metro::Plugin::Hook::StreamStations
+Map::Metro::Plugin::Hook::StreamStations - Prints stations as they are parsed
 
 =head1 VERSION
 
-Version 0.2208, released 2015-10-27.
+Version 0.2300, released 2016-01-14.
 
 =head1 SOURCE
 
@@ -61,7 +63,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
