@@ -2,14 +2,17 @@ use 5.16.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.2208'; # VERSION
+our $VERSION = '0.2300'; # VERSION
+# ABSTRACT: Extends Moops
 
 package #
     Map::Metro::Standard::Moops {
 
-    use base 'Moops';
+    use base 'MoopsX::UsingMoose';
     use List::Util 1.33 ();
     use Map::Metro::Types();
+    use Types::Standard();
+    use Types::Path::Tiny();
     use Eponymous::Hash();
     use List::Compare();
     use MooseX::SetOnce();
@@ -24,6 +27,8 @@ package #
             'Eponymous::Hash'   => ['eh'],
             'String::Trim'      => ['trim'],
             'feature'           => [qw/:5.16/],
+            'Types::Standard'   => [{ replace => 1 }, '-types'],
+            'Types::Path::Tiny' => [{ replace => 1 }, '-types'],
             'Map::Metro::Types' => [{ replace => 1 }, '-types'],
             'List::Compare'     => [],
             'MooseX::SetOnce'   => [],
@@ -44,11 +49,11 @@ __END__
 
 =head1 NAME
 
-Map::Metro::Standard::Moops
+Map::Metro::Standard::Moops - Extends Moops
 
 =head1 VERSION
 
-Version 0.2208, released 2015-10-27.
+Version 0.2300, released 2016-01-14.
 
 =head1 SOURCE
 
@@ -64,7 +69,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
