@@ -3,14 +3,12 @@ use Moops;
 use strict;
 use warnings;
 
-our $VERSION = '0.2208'; # VERSION
+our $VERSION = '0.2300'; # VERSION
 # PODNAME: Map::Metro::Types
+# ABSTRACT: Type library for Map::Metro
 
 library  Map::Metro::Types
 
-extends  Types::Standard,
-         Types::Path::Tiny
-
 declares Connection,
          Line,
          LineStation,
@@ -43,11 +41,11 @@ __END__
 
 =head1 NAME
 
-Map::Metro::Types
+Map::Metro::Types - Type library for Map::Metro
 
 =head1 VERSION
 
-Version 0.2208, released 2015-10-27.
+Version 0.2300, released 2016-01-14.
 
 =head1 SOURCE
 
@@ -63,7 +61,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
